==> snipe-it-7.0.13.zip: snipe-it-7.0.13/resources/lang/so-SO/admin/accessories/message.php <==
<?php

return array(

    'does_not_exist' => 'Qalabka [:id] ma jiro',
    'not_found' => 'Qalabkaas lama helin.',
    'assoc_users'	 => 'Qalabkan waxa uu hadda hayaa :count walxo la hubiyay isticmaalayaasha Fadlan iska hubi agabka oo isku day markale. ',

    'create' => array(
        'error'   => 'Qalabka lama abuurin, fadlan isku day mar kale.',
        'success' => 'Qalabka si guul leh ayaa loo sameeyay'
    ),

    'update' => array(
        'error'   => 'Qalabka lama cusboonaysiin, fadlan isku day mar kale',
        'success' => 'Qalabka si guul leh ayaa loo cusboonaysiiyay'
    ),

    'delete' => array(
        'confirm'   => 'Ma hubtaa inaad rabto inaad tirtirto qalabkan?',
        'error'   => 'Waxaa jiray arrin la tirtiray qalabyada Fadlan isku day mar kale',
        'success' => 'Qalabka si guul leh ayaa loo tirtiray'
    ),

     'checkout' => array(
        'error'   		=> 'Agabka lama hubin, fadlan isku day mar kale',
        'success' 		=> 'Qalabka si guul leh ayaa loo hubiyay',
        'unavailable'   => 'Agabka looma hayo hubinta Hubi tirada la heli karo',
        'user_does_not_exist' => 'Isticmaalahaasi waa khalad Fadlan isku day mar kale',
         'checkout_qty' => array(
            'lte'  => 'There is currently only one available accessory of this type, and you are trying to check out :checkout_qty. Please adjust the checkout quantity or the total stock of this accessory and try again.|There are :number_currently_remaining total available accessories, and you are trying to check out :checkout_qty. Please adjust the checkout quantity or the total stock of this accessory and try again.',
            ),
           
    ),

    'checkin' => array(
        'error'   		=> 'Agabka lama hubin, fadlan isku day mar kale',
        'success' 		=> 'Qalabka si guul leh ayaa loo hubiyay',
        'user_does_not_exist' => 'Isticmaalahaasi waa khalad Fadlan isku day mar kale'
    )


);

==> snipe-it-8.3.3.zip: snipe-it-8.3.3/resources/lang/so-SO/admin/accessories/message.php <==
<?php

return array(

    'does_not_exist' => 'Mulxaqa lasoo raaciyay [:aqoonsiga] ma ahan mid jira.',
    'not_found' => 'Qalabkaas lama helin.',
    'assoc_users'	 => 'Qalabkan waxa uu hadda hayaa :count walxo la hubiyay isticmaalayaasha Fadlan iska hubi agabka oo isku day markale. ',

    'create' => array(
        'error'   => 'Qalabka lama abuurin, fadlan isku day mar kale.',
        'success' => 'Mulxaqa lasoo raaciyay waa lagu guuleystay in la sameeyo.'
    ),

    'update' => array(
        'error'   => 'Qalabka lama cusboonaysiin, fadlan isku day mar kale',
        'success' => 'Mulxaqa lasoo raaciyay waa lagu guuleystay in la sameeyo.'
    ),

    'delete' => array(
        'confirm'   => 'Ma hubtaa inaad rabto inaad tirtirto qalabkan?',
        'error'   => 'Waxaa jirtay xaalad tirtireysay mulxaqa. Fadlan isku day mar kale.',
        'success' => 'Mulxaqa lasoo raaciyay waa lagu guuleystay in la tir-tiro.'
    ),

     'checkout' => array(
        'error'   		=> 'Agabka lama hubin, fadlan isku day mar kale',
        'success' 		=> 'Mulxaqa lasoo raaciyay waa lagu guuleystay in la hubiyo.',
        'unavailable'   => 'Agabka looma hayo hubinta Hubi tirada la heli karo',
        'user_does_not_exist' => 'Isticmaalahaas maahan mid jira. Fadlan isku day mar kale.',
         'checkout_qty' => array(
            'lte'  => 'There is currently only one available accessory of this type, and you are trying to check out :checkout_qty. Please adjust the checkout quantity or the total stock of this accessory and try again.|There are :number_currently_remaining total available accessories, and you are trying to check out :checkout_qty. Please adjust the checkout quantity or the total stock of this accessory and try again.',
            ),
           
    ),

    'checkin' => array(
        'error'   		=> 'Agabka lama hubin, fadlan isku day mar kale',
        'success' 		=> 'Mulxaqa waa lagu guuleystay in la hubiyo.',
        'user_does_not_exist' => 'Isticmaalahaasi mahan mid jira. Fadlan isku day mar kale.'
    )


);
